/******************************************************************************
 * Copyright(c) 1998 INTERSOLV, Inc, All rights reserved
 * swevperf.h : SwaN Event API
 * $Revision:   1.2  $
 *
 * Description
 *		Types, functions and constants for the shared memory counters
 *		and performance monitor interface
 *
 * Remarks:
 *
 * To Do
 *
 * Edit Log
 * $Log:   \\Belgdev1\U\sqlnkdev\slxrep\archives\SWSL\src\swevperf.h-arc  $
  * 
  *    Rev 1.2   Jan 25 2000 15:05:54   JanC
  * Increased kSWEV_PERF_NRSERVICECNTRDEFS	
  * 
  *    Rev 1.1   06 Aug 1999 11:53:34   PeterC
  * Increased shared counter define (to be verified by jc)
  * 
  *    Rev 1.0   19 Apr 1999 14:18:02   JanC
  * From SWSCORE, Rev 1.4
  * Reset Edit Log
 *
 *****************************************************************************/

#ifndef swevperf_h
#define swevperf_h

/******************************************************************************
 * Include's
 *****************************************************************************/
#include "platform.h"
#include "swevent.h"
#include "swevipc.h"

#ifdef PLTF_WIN32
#include <winperf.h>
#endif

/******************************************************************************
 *	Identification
 ******************************************************************************/
PLTF_PVCSSETVERSION_H(swevperf, $Revision:   1.2  $, $Date::   Jan 25 2000$)

/******************************************************************************
 * Defines
 *****************************************************************************/

#ifdef PLTF_WIN32

/*
 * Object and counter numbers for Performance Monitor.
 * (must be a multiple of 2)
 */
#define SWEVPERF_OBJECT1			0
#define SWEVPERF_CNTR1				2
#define SWEVPERF_CNTR2				4
#define SWEVPERF_CNTR3				6
#define SWEVPERF_CNTR4				8
#define SWEVPERF_CNTR5				10
#define SWEVPERF_CNTR6				12
#define SWEVPERF_CNTR7				14
#define SWEVPERF_CNTR8				16
#define SWEVPERF_CNTR9				18
#define SWEVPERF_CNTR10				20
#define SWEVPERF_CNTR11				22
#define SWEVPERF_CNTR12				24
#define SWEVPERF_CNTR13				26
#define SWEVPERF_CNTR14				28
#define SWEVPERF_CNTR15				30
#define SWEVPERF_CNTR16				32
#define SWEVPERF_CNTR17				34
#define SWEVPERF_CNTR18				36
#define SWEVPERF_CNTR19				38
#define SWEVPERF_CNTR20				40

#endif	/* #ifdef PLTF_WIN32 */

#define kSWEV_PERF_NRSERVICECNTRS				9
#define kSWEV_PERF_NRSERVICECNTRDEFS		12

/******************************************************************************
 * Typedefs
 *****************************************************************************/

#ifdef PLTF_WIN32
#pragma pack (8)

/*
 * insure packing is done to the 8 byte align longlong data values. This
 * will eliminate alignment faults on RISC platforms. The fields can be
 * manually arranged to minimize or eliminate wasted space if necessary.
 */

typedef struct
	{
	PERF_OBJECT_TYPE					objectType;
	PERF_COUNTER_DEFINITION		counterDef[kSWEV_PERF_NRSERVICECNTRDEFS];
	} SWEV_PERFMON_SERVICECNTRS_DEF;

typedef struct tagSWEV_PERFMONCOUNTER *SWEV_PERFMONCOUNTERPtr;
typedef struct tagSWEV_PERFMONCOUNTER
	{
	PERF_COUNTER_BLOCK      CounterBlock;
	int32										counter[kSWEV_PERF_NRSERVICECNTRS];
	}SWEV_PERFMONCOUNTER;

#pragma pack ()

#endif /* ifdef PLTF_WIN32 */

#if defined PLTF_AS400 || defined PLTF_UNIX || defined PLTF_MVS
typedef struct
	{
	int32										dummy;
	}PERF_COUNTER_BLOCK;
#endif /* #if defined PLTF_AS400 || defined PLTF_UNIX */

typedef struct tagSWEV_SHAREDCOUNTER *SWEV_SHAREDCOUNTERPtr;
typedef struct tagSWEV_SHAREDCOUNTER
	{
	PERF_COUNTER_BLOCK      CounterBlock;
	int32										counter[kSWEV_PERF_NRSERVICECNTRS];
	int32										inUse;
	int32										type;
	SWEV_SERVICENAME				instanceName;
	}SWEV_SHAREDCOUNTER;

typedef struct tagSWEV_SHMMONITORDATA *SWEV_SHMMONITORDATAPtr;
typedef struct tagSWEV_SHMMONITORDATA
	{
	uint32									shmSize;
	uint32									maxInstances;
	uint32									lastIndex;
	SWEV_SHAREDCOUNTER			instances[1];
	}SWEV_SHMMONITORDATA;

typedef struct tagSWEV_SHMMONITOR *SWEV_SHMMONITORPtr;
typedef struct tagSWEV_SHMMONITOR *SWEV_SHMMONITORHandle;
typedef struct tagSWEV_SHMMONITOR
	{
#ifndef PLTF_MVS
  SHM_ID									id;
#endif /* PLTF_MVS */
	SWEV_SHMMONITORDATAPtr	shmPtr;
	}SWEV_SHMMONITOR;

typedef struct tagSWEV_SHMMONITORPARAM *SWEV_SHMMONITORPARAMPtr;
typedef struct tagSWEV_SHMMONITORPARAM
	{
	int32										shmSize;
	}SWEV_SHMMONITORPARAM;
/******************************************************************************
 * Functions
 *****************************************************************************/
#ifdef __cplusplus
extern "C" {
#endif /* #ifdef __cplusplus */

SWEV_API SharedMonitor_Attach					(	SWEV_SHMMONITORHandle		*ioShMonitor,
																				const char							*iQueueId,
																				int32										ibAgent,
																				const SWEV_SHMMONITORPARAM	*iParam,
																				ERRSTKPtr								iErrStack);

SWEV_API SharedMonitor_Detach					(	SWEV_SHMMONITORHandle		iHandle,
																				int32										ibAgent,
																				ERRSTKPtr								iErrStack);

#ifdef __cplusplus
}
#endif /* #ifdef __cplusplus */


#endif /* #ifndef swevperf_h */

/* end of file */
